<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT" sourcelanguage="it_IT">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Clicca per tornare all&apos;applicazione</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Scarica</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 oggetti</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nome del file</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Prova di nuovo</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Pubblica su YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autore</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Lavagna</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenti</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Stilo</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Sfondi</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Cambia sfondo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rifai</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgSu</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Pagina successiva</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgGiù</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Gestione documenti</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Navigazione web</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Tratto</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Tratto fine</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Tratto medio</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Tratto grosso</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Gomma</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Gomma piccola</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Gomma media</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Gomma grande</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Colore</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Ricarica pagina corrente</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Carica homepage</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Segnalibri</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Visualizza segnalibri</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Segnalibro</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Aggiungi segnalibro</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Visualizza lavagna</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Cancella contenuto</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Visualizza preferenze</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Visualizza biblioteca</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Mostra desktop</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Mostra il desktop del computer</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Più grande</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zoom avanti</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Più piccolo</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zoom indietro</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nuova cartella</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Crea nuova cartella</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nuovo documento</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Crea un nuovo documento</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importa un documento</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Esporta un documento</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Apri nella lavagna</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Apri la pagina nella lavagna</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplica il contenuto selezionato</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Elimina il contenuto selezionato</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Aggiungi al documento di lavoro</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Aggiungi il contenuto selezionato al documento aperto</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Aggiungi il contenuto al documento</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Rinomina il contenuto</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Visualizza strumenti</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multischermo</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Formato largo (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Usa il formato largo (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Formato normale (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Usa il formato normale (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Formato personalizzato</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Usa il formato personalizzato</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Ferma il caricamento</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Ferma il caricamento della pagina web</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Sospendi la presentazione</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Tastiera virtuale</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Visualizza la tastiera virtuale</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Sfondo chiaro semplice</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Chiaro</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Sfondo chiaro con griglia</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Sfondo scuro semplice</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Scuro</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Sfondo scuro con griglia</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Registra presentazione come video</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Registra</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Inizia registrazione schermo</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Cancella oggetti</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Cancella tutti gli oggetti</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Cancella annotazioni</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Cancella tutte le annotazioni</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Pulisci pagina</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Pulisci tutti gli elementi</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Annota documento</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Cancella l&apos;annotazione</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Evidenziatore</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Evidenzia </translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Selettore</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Seleziona e modifica oggetti</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Mano</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Scorri pagina</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Puntatore laser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Puntatore laser virtuale</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Disegna linee</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Scrivi testo</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Cattura</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Cattura parte dello schermo</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Aggiungi alla pagina corrente</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Aggiungi oggetto alla pagina corrente</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Aggiungi a nuova pagina</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Aggiungi oggetto a nuova pagina</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Aggiungi alla biblioteca</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Aggiungi oggetto alla biblioteca</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Pagine</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Crea una nuova pagina</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nuova pagina</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplica pagina</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplica la pagina corrente</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importa pagina</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importa una pagina esterna</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Ferma la registrazione del Podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Configurazione Podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configura la registrazione del Podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Cattura Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Cattura contenuto flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Cattura Web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Cattura contenuto web</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Cattura personalizzata</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Cattura della finestra</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Cattura una finestra</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Incorpora contenuto web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Cattura un contenuto web incorporabile</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Visualizza sullo schermo</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Visualizza lo schermo principale sullo schermo</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Cancella tutte le annotazioni</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>EduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importa simulatore eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Chiudi OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Nascondi OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Nascondi l&apos;applicazione OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interagisci con gli oggetti</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Cancella sfondo</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Rimuove lo sfondo</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Apri tutorial</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Apri la pagina web del tutorial</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Sfondo chiaro a righe</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Sfondo scuro a righe</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Ripristina la dimensione della griglia</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation>Gomma piccola</translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation>Colore 1</translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation>Colore 2</translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation>Colore 3</translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation>Colore 4</translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation>Colore 5</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>disegna linee di griglia intermedie</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Autenticazione richiesta</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticazione Proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Connessione al Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Salva nome utente e password per usi futuri</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Elemento ID =</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Il contenuto non è supportato nel formato di destinazione.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Rimuovi pagina</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Sei sicuro di voler rimuovere 1 pagina dal documento selezionato &apos;%0&apos;?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Dimensione pagina</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>PodCast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Nuovo aggiornamento disponibile, vuoi andare alla pagina web?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Nessun aggiornamento disponibile</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Aggiornamento disponibile</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiornamento</translation>
    </message>
    <message>
        <source>Board drawing...</source>
        <translation type="vanished">Disegno della lavagna...</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Dimensione della griglia</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>disegna linee di griglia intermedie</translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Download contenuto %1 fallito</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Download completato</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Tipo di strumento %1 sconosciuto</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Tipo di contentuto %1 sconosciuto</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Aggiungi oggetto</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Tutto supportato (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Rimuovi pagina %1 dal documento</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Pagina %1 rimossa</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Operazione di aggiunta file fallita: errore nella copia file</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Raggruppa</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Separa</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Salvataggio documento...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Il documento è stato appena salvato...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>eliminazione della pagina %1</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Colore</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Errore aggiungendo l&apos;immagine alla biblioteca</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>ImmagineCatturata</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Caricamento pagina (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Proprietà della cache</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Cattura parte dello schermo</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Cattura lo schermo</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Mostra la palette dello stilo</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Mostra la lavagna sullo schermo secondario</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Mostra il desktop sullo schermo secondario</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Mostra OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Nuova cartella</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Pagina %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Aggiungi cartella di immagini</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Aggiungi immagini</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Aggiungi pagine da file</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Sto duplicando il documento %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Documento %1 copiato</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Elimina pagina</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Elimina documento</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Sei sicuro di voler eliminare il documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Svuota il cestino</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Sei sicuro di voler svuotare il cestino?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Sto svuotanto il cestino</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Cestino svuotato</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Elimina cartella</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Sei sicuro di voler eliminare la cartella &apos;%1&apos; e tutto il suo contenuto?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Nessun documento selezionato!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Apri file supportato</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Sto importanto il file %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Importazione del file fallita... </translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importa tutte le immagini dalla cartella</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vuoto</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Apri documento</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Aggiungi tutte le immagini al documento</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Tutte le immagini (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>La selezione non contiene nessun file immagine!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Sei sicuro di voler rimuovere %n pagina dal documento &apos;%1&apos; selezionato?</numerusform>
            <numerusform>Sei sicuro di voler rimuovere %n pagine dal documento &apos;%1&apos; selezionato?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>La cartella non contiene alcun file immagine</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documenti senza titolo</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>Il documento &quot;%1&quot; è stato generato con una più recente versione di OpenBoard (%2). Aprendolo, si possono perdere alcune informazioni. Procedere ugualmente?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Sicuri di voler rimuovere tutti i documenti selezionati?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Rimuovi documenti multipli</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation>
            <numerusform>%1 pagina copiata</numerusform>
            <numerusform>%1 pagine copiate</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Cancella oggetti</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Sei sicuro di voler cancellare l&apos;(gli) item selezionato(i)?</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>Frontespizio</translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>immagini</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>video</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>oggetti</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widget</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Tutti i file supportati (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>File %1 salvato</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Inserimento di pagina %1 di %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importazione riuscita.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Importazione del file %1 riuscita.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Sto importando il file %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Esportazione fallita.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>Accetta</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation>Il nome %1 è già usato.
Conservando questo nome si sostituirà il documento.
Dando un nuovo nome si creerà un nuovo documento.</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation>I miei documenti</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 pagina copiata</numerusform>
            <numerusform>%1 pagine copiate</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 pagina copiata</numerusform>
            <numerusform>%1 pagine copiate</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Cancella oggetti</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Sei sicuro di voler cancellare l&apos;(gli) item selezionato(i)?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation>Sto copiando pagina %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (copia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Sto copiando pagina %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 pagina copiata</numerusform>
            <numerusform>%1 pagine copiate</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Download in corso</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation>Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>È apparso un avviso durante l&apos;esportazione</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Esportazione fallita</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>Impossibile esportare nella posizione selezionata. Non possiedi i permessi necessari a salvare il file.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Esportazione fallita: posizione non scrivibile</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Esportazione riuscita.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Esporta in IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Esporta come file IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Esportazione conclusa con successo.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Esportazione fallita.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Esporta come file UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Esportazione completata con successo.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Esportazione %1 %2 di %3 in corso</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Esporta nel formato OpenBoard</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Exportazione fallita: posizione non scrivibile</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Esportazione fallita</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Impossibile esportare nella posizione selezionata. Non possiedi i permessi necessari a salvare il file.</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation>Esportazione fallita...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>Esporta come file UBX</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Esportazione riuscita.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Esportazione fallita.</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>Esporta nel formato OpenBoard UBX</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Esporta come PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Esportazione completata con successo.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Esporta in PDF</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Esportazione fallita: posizione non scrivibile</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Esportazione fallita</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Impossibile esportare alla posizione selezionata. Non possiedi i permessi necessari a salvare il file.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Esporta come file PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Esportazione riuscita.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Esportazione pagina %1 di %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Esporta in PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Esporta come dati Web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Esportazione documento in corso...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Esportazione completata con successo.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Esportazione fallita.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Esporta nel browser web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Aggiungi alla pagina</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Imposta come sfondo</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Aggiungi alla Biblioteca</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informazioni sull&apos;oggetto</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Aggiungi ai preferiti</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Condividi</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Torna alla cartella</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Rimuovi dai preferiti</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Crea nuova cartella</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Ripeti la scansione del file system</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>ImmagineImportata</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmati</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animazioni</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interattività</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Applicazioni</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Forme</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Ricerca web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Cestino</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Accetta</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Inserisci un nuovo nome di cartella</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Caricamento in corso </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloccato</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visibile sullo schermo esteso</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloccato</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visibile sullo schermo esteso</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Vai alla sorgente del contenuto</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Imposta come sfondo</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>La risorsa multimediale non può essere gestita</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Formato multimediale non supportato</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Servizio di esecuzione multimediale non trovato</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Errore multimediale: </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Inserisci il testo qui&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Colore testo</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Modificabile</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Caricamento in corso...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Congelato</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Trasforma in strumento </translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Common File Format (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importazione del file %1 in corso...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>L&apos;importazione del file %1 è fallita.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importazione completata con successo.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Importazione fallita.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importazione del file %1 in corso...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importazione completata con successo.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>L&apos;importazione del file %1 è fallita.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation>Openboard (insieme di documenti) (*.ubx)</translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Formato immagine (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Importazione del PDF fallita.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importazione della pagina %1 di %2 in corso</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Errore nella pubblicazione del video in intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Pubblicazione in intranet in corso %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Pubblica</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Invio</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Inserisci username e password per &quot;%1&quot; al %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Login al proxy fallito</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Errori SSL:

%1

%2

Vuoi ignorare gli errori per questo host?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Rilevati documenti Open-Sankore</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Mostra questo pannello la prossima volta</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>È sempre possibile accedere all&apos;importatore di documenti OpenBoard tramite il pannello delle preferenze nella scheda delle informazioni su OpenBoard. Attenzione, se si è già importato dati Open-Sankore, è possibile perdere i documenti OpenBoard correnti.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Procedi</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Documenti Open-Sankoré sono presenti nel computer. È possibile importarli in OpenBoard premendo il pulsante “Procedi” per avviare l&apos;applicazione di importazione.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(copia)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Perdita archivio documenti</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">ha perso l&apos;accesso al repository documenti &quot;%1&quot;. Sfortunatamente l&apos;applicazione deve essere chiusa per evitare di rovinare i dati. Gli ultimi cambiamenti potrebbero andare persi.</translation>
    </message>
    <message>
        <source>Saving thumbnail of page %1</source>
        <translation type="vanished">Salvataggio della miniatura della pagina %1</translation>
    </message>
    <message>
        <source>Moving page to trash folder...</source>
        <translation type="vanished">Spostamento della pagina nella cartella del cestino...</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation>OpenBoard ha perso l&apos;accesso al repository documenti &quot;%1&quot;. Sfortunatamente l&apos;applicazione deve essere chiusa per evitare di rovinare i dati. Gli ultimi cambiamenti potrebbero andare persi.</translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francese</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Francese Svizzero</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Impossibile avviare il codificatore...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Nessun codificatore Podcast disponibile ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Parte %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>sul tuo desktop ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>nella cartella %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast creato %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Errore registrazione Podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Ingresso audio predefinito</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Nessuna registrazione audio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Piccolo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Pieno</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Pubblica in Intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Pubblica su Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versione:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>L&apos;evidenziatore è sensibile alla pressione</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Login Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nome utente:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Password:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Pubblica documento sul web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titolo:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descrizione:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Pubblica</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>I miei film</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Visibile la prossima volta</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Generazione della miniatura di anteprima in corso...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniature generate...</translation>
    </message>
    <message>
        <source>loading thumbnail of page %1</source>
        <translation type="vanished">Caricamento miniatura della pagina %1</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Maschera</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Righello</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Compasso</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Goniometro</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Squadra</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lente</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation>Assi</translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Pagina intera</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Aggiorna documento</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> i file necessitano di un aggiornamento.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Percorso di backup: </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Sfoglia</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Seleziona una cartella di backup</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Aggiornamento file eseguito!
Si prega di riavviare l&apos;applicazione per accedere ai documenti aggiornati.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Si è verificato un errore durante l&apos;aggiornamento. I file non sono stati coinvolti.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Risultati dell&apos;aggiornamento dei file</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Aggiornamento file in corso </translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Si prega di attendere. Il processo di importazione inizierà a breve...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Ricordamelo in seguito</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Caricamento in corso...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 chiamati (metodo=%1, stato=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Autenticazione su YouTube fallita.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Errore durante il caricamento del video su YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Caricamento su YouTube in corso %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Caricamento</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Auto e veicoli</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Animali</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Viaggi ed eventi</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Giochi</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Commedia</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Persone e blog</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Attualità e politica</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Intrattenimento</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Istruzione</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Howto e stile</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Non profit ed attivismo</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Scienza e tecnologia</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Salva file</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Download annullato: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Errore nell&apos;apertura del file salvato: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Errore nel salvataggio: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Errore di rete: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondi</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuti</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 ancora da scaricare</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 di %2 (%3/sec) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 di %2 - Interrotto</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Download</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Download</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Oggi prima</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 oggetti</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nuova &amp;Scheda</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Clona scheda</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Chiudi scheda</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Chiudi &amp;Altre schede</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Ricarica scheda</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Ricarica tutte le schede</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Schede chiuse di recente</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Senza titolo)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Nessuna ricerca recente</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Ricerche recenti</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Cancella le ricerche recenti</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Scarica</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Aggiungi al documento corrente</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Errore nel caricamento della pagina: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Scarica il documento PDF: preferisci scaricare il file PDF o aggiungerlo al documento OpenBoard corrente?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Apri in una nuova scheda</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation>Processo in corso…</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Pubblica Podcast su Youtube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Parole chiave</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nome utente Youtube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Password Youtube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Premendo &apos;Upload&apos;,  certifichi di possedere tutti i diritti sul contenuto o di essere stato autorizzato dal proprietario a rendere questi contenuti pubblici su Youtube, e che in ogni modo siano conformi ai termini di utilizzo di Youtube che puoi trovare all&apos;indirizzo: &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Ripristina le credenziali al riavvio</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Su sfondo chiaro</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Su sfondo scuro</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacità</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Larghezza tratto</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Grosso</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Sottile</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>La penna è sensibile alla pressione</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Mostra l&apos;anteprima del cerchio a partire da</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autore</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="vanished">Titolo</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="vanished">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="vanished">Autore</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Descrizione</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Documenti OpenBoard</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Data di creazione</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Data di modifica</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Ordine alfabetico</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Ordinamento</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versione : ...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Impostazioni predefinite</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Schermo</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Visualizza la pagina con un browser esterno</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Homepage:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Tastiera virtuale</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Dimensione pulsanti tastiera:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Posizionata in alto (consigliato per tablet)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Posizionata in basso (consigliato per lavagne)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Visualizza testo sotto il pulsante</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Palette stilo</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penna</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Evidenziatore</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Aggiorna il software</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>All&apos;avvio controlla gli aggiornamenti del software disponibili</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenze</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Mostra il contenuto interno della pagina web sullo schermo secondario o sul proiettore</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Multi schermo</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Scambia lo schermo di controllo con quello di visualizzazione</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Modalità di avvio:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Lavagna</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Utente proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Riconoscimenti</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Apri l&apos;importatore Open-Sankoré</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Controlla se i dati Open-Sankoré possono venir importati all&apos;avvio</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Usa la tastiera di sistema (raccomandato)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Dimensione pulsanti tastiera virtuale incorporata:</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Griglia</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Su sfondo chiaro</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacità</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Su sfondo scuro</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Scambia lo schermo di controllo con quello di visualizzazione</translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation>Modalità Documenti</translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation>Visualizza la colonna delle date con ordinamento alfabetico.</translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation>Cancellare dal cestino i documenti di étà superiore a</translation>
    </message>
    <message>
        <source>days</source>
        <translation>giorni</translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation>rendering PDF</translation>
    </message>
    <message>
        <source>Enable quality loss to increase zoom performances</source>
        <translation type="vanished">Permettere una perdita di qualità per aumentare le prestazioni dello zoom</translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation>Migliorare la velocità dello zoom (può influire leggermente sulla qualità del rendering)</translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Cattura flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Seleziona un&apos;applicazione flash da catturare</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nome applicazione</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Crea applicazione</translation>
    </message>
</context>
</TS>
